from typing import List, Any

from pydantic import BaseModel, validator

from tracardi.domain.entity import Entity


class Configuration(BaseModel):
    source: Entity
    type: str = 'select'
    query: str = "SELECT 1"
    data: List[Any] = []
    timeout: int = None

    @validator("query")
    def must_not_be_empty(cls, value):
        if len(value) < 2:
            raise ValueError("Sql must not be empty.")
        return value

    @validator("type")
    def must_have_certain_value(cls, value):
        allowed_values = ['select', 'insert', 'delete', 'call', 'create']
        if value not in allowed_values:
            raise ValueError(f"Allowed values {allowed_values}")
        return value
